==> CGTweet-1.1.tar.gz: CGTweet/lang/en_US.php <==
<?php

#A
$lang['access_token'] = 'Access Token';
$lang['access_token_secret'] = 'Access Token Secret';
$lang['authtemplates'] = 'Authorization Templates';
$lang['authorize_via_twitter'] = 'Authorize via Twitter';

#B

#C
$lang['consumer_secret'] = 'Consumer Secret';
$lang['consumer_key'] = 'Consumer Key';

#D
$lang['dflt_templates'] = 'Default Templates';

#E
$lang['error_access_settings'] = 'Access token and access secret are empty or invalid';
$lang['error_accesstokens'] = 'Error retrieving access tokens';
$lang['error_connect'] = 'Error connecting or authenticating to twitter services';
$lang['error_consumer_settings'] = 'Consumer key and secret are empty or invalid';
$lang['error_credentials'] = 'Attempt to send a message but access token or other credentials are empty or invalid';
$lang['error_credentials2'] = 'Access token or other credentials are empty or invalid';
$lang['error_nofeu'] = 'Could not get the FEU module to get/set CGTWeet User key';
$lang['error_invalidmessage'] = 'The message supplied was invalid (missing body or another required parameter)';
$lang['error_invaliduid'] = 'Invalid User ID %s';

#F
$lang['friendlyname'] = 'Calguys Tweet Module';

#G

#H
$lang['help_action'] = 'Determine the behavior of the module on a frontend request.  Possible values are: &quot;authorize&quot; and &quot;timeline&quot;.  This module has no default action.';
$lang['help_authtemplate'] = 'Applicable only to the &quot;authorize&quot; action, it allows specifying the name of a non default authorization template.';
$lang['help_count'] = '(integer) Applicable only to the &quot;timeline&quot; action, this parameter specifies the number of tweets to display.  The default value is 20';
$lang['help_deep'] = '(integer) Applicable only to the &quot;timeline&quot; action, this parameter specifies that entities (such as media, urls, hashtags etc) in the output.  By default this option is off.';
$lang['help_noreplies'] = '(integer) Applicable only to the &quot;timeline&quot; action.  This parameter can be used to exclude replies to tweets in the generated output.  By default replies will be included.';
$lang['help_inline'] = '(integer) Applicable only to the &quot;authorize&quot; action, this parameter specifies that the form should be created inline. Any non zero value can be specified.';
$lang['help_retweets'] = '(integer) Applicable only to the &quot;timeline&quot; action.  This parameter can be used to include retweets in the generated output.  By default this option is off.';
$lang['help_timelinetemplate'] = 'Applicable only to the &quot;timeline&quot; action.  This parameter allows specifying the name of a non default timeline template';
$lang['homepage'] = 'Home Page';

#I
$lang['info_account_settings'] = 'A user access token, and token secret are needed in order to send status updates etc.  You can obtain these directly from twitter, or use the &quot;Authorize via Twitter&quot; link below.';
$lang['info_app_settings'] = 'You need to specify the consumer key and consumer secret from your twitter app.  These can be found under &quot;My Applications&quot; at <a href="http://dev.twitter.com">dev.twitter.com</a>';
$lang['info_friendlyname'] = 'This specifies the name of the module in the admin navigation.  You may need to clear the site cache after changing this setting';
$lang['info_sender_twitter'] = 'Twitter messages are a maximum of 140 characters long. <strong>Note:</strong> It is reported that that limit is reduced to 117 or 118 characters if a link is included with the tweet. HTML code is not supported in the status';
$lang['info_shorten_urls'] = 'If a suitable module is found, and this option is enabled, URLS in outgoing tweets can be shortened';

#J

#K

#L

#M
$lang['moddescription'] = 'A module for sending tweets';
$lang['msg_accesstokens_good'] = 'Access tokens received';
$lang['msg_auth_known'] = 'Your authentication credentials are securely stored and ready to use';
$lang['msg_auth_success'] = 'Authorization Successfull';
$lang['msg_tweetsent'] = 'Tweet successfully sent';

#N

#O

#P
$lang['postinstall'] = 'The module has been installed.  Please visit the modules admin panel to set the authorization tokens';
$lang['postuninstall'] = 'The module has been successfully uninstalled, and all data related to this module permanently removed';
$lang['prompt_friendlyname'] = 'Module Friendly Name';
$lang['prompt_shorten_urls'] = 'Shorten URLS';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you want to remove this module?  Uninstalling will remove all known twitter credentials for any users and may break a functioning website.';

#S
$lang['send_test_tweet'] = 'Send Test Tweet';
$lang['settings'] = 'Settings';
$lang['settings_changed'] = 'Settings updated';
$lang['submit'] = 'Submit';

#T
$lang['timelinetemplates'] = 'Timeline Templates';
$lang['title_addedit_authtemplate'] = 'Add or Edit an Authorization Template';
$lang['title_addedit_timeline'] = 'Add or Edit a Timeline Template';
$lang['title_app_settings'] = 'Twitter App Settings';
$lang['title_general_settings'] = 'General Settings';
$lang['title_sysdflt_authtemplate'] = 'System Default Authorization Template';
$lang['title_sysdflt_timeline'] = 'System Default Timeline Template';
$lang['twitter_account_settings'] = 'Twitter Account Settings';

#U

#V
$lang['via'] = 'via';

#W

#X

#Y

#Z

?>

==> CGTweet-1.1.1.tar.gz: CGTweet/lang/en_US.php <==
<?php

#A
$lang['access_token'] = 'Access Token';
$lang['access_token_secret'] = 'Access Token Secret';
$lang['authtemplates'] = 'Authorization Templates';
$lang['authorize_via_twitter'] = 'Authorize via Twitter';

#B

#C
$lang['consumer_secret'] = 'Consumer Secret';
$lang['consumer_key'] = 'Consumer Key';

#D
$lang['dflt_templates'] = 'Default Templates';

#E
$lang['error_access_settings'] = 'Access token and access secret are empty or invalid';
$lang['error_accesstokens'] = 'Error retrieving access tokens';
$lang['error_connect'] = 'Error connecting or authenticating to twitter services';
$lang['error_consumer_settings'] = 'Consumer key and secret are empty or invalid';
$lang['error_credentials'] = 'Attempt to send a message but access token or other credentials are empty or invalid';
$lang['error_credentials2'] = 'Access token or other credentials are empty or invalid';
$lang['error_nofeu'] = 'Could not get the FEU module to get/set CGTWeet User key';
$lang['error_invalidmessage'] = 'The message supplied was invalid (missing body or another required parameter)';
$lang['error_invaliduid'] = 'Invalid User ID %s';

#F
$lang['friendlyname'] = 'Calguys Tweet Module';

#G

#H
$lang['help_action'] = 'Determine the behavior of the module on a frontend request.  Possible values are: &quot;authorize&quot; and &quot;timeline&quot;.  This module has no default action.';
$lang['help_authtemplate'] = 'Applicable only to the &quot;authorize&quot; action, it allows specifying the name of a non default authorization template.';
$lang['help_count'] = '(integer) Applicable only to the &quot;timeline&quot; action, this parameter specifies the number of tweets to display.  The default value is 20';
$lang['help_deep'] = '(integer) Applicable only to the &quot;timeline&quot; action, this parameter specifies that entities (such as media, urls, hashtags etc) in the output.  By default this option is off.';
$lang['help_noreplies'] = '(integer) Applicable only to the &quot;timeline&quot; action.  This parameter can be used to exclude replies to tweets in the generated output.  By default replies will be included.';
$lang['help_inline'] = '(integer) Applicable only to the &quot;authorize&quot; action, this parameter specifies that the form should be created inline. Any non zero value can be specified.';
$lang['help_retweets'] = '(integer) Applicable only to the &quot;timeline&quot; action.  This parameter can be used to include retweets in the generated output.  By default this option is off.';
$lang['help_timelinetemplate'] = 'Applicable only to the &quot;timeline&quot; action.  This parameter allows specifying the name of a non default timeline template';
$lang['homepage'] = 'Home Page';

#I
$lang['info_account_settings'] = 'A user access token, and token secret are needed in order to send status updates etc.  You can obtain these directly from twitter, or use the &quot;Authorize via Twitter&quot; link below.';
$lang['info_app_settings'] = 'You need to specify the consumer key and consumer secret from your twitter app.  These can be found under &quot;My Applications&quot; at <a href="http://dev.twitter.com">dev.twitter.com</a>';
$lang['info_friendlyname'] = 'This specifies the name of the module in the admin navigation.  You may need to clear the site cache after changing this setting';
$lang['info_sender_twitter'] = 'Twitter messages are a maximum of 140 characters long. <strong>Note:</strong> It has been reported that twitter counts each and every URL as having 20 characters and automatically shortens URLS of 19 characters or more.  Any character count is just an approximation.';
$lang['info_shorten_urls'] = 'If a suitable module is found, and this option is enabled, URLS in outgoing tweets can be shortened';

#J

#K

#L

#M
$lang['moddescription'] = 'A module for sending tweets';
$lang['msg_accesstokens_good'] = 'Access tokens received';
$lang['msg_auth_known'] = 'Your authentication credentials are securely stored and ready to use';
$lang['msg_auth_success'] = 'Authorization Successfull';
$lang['msg_tweetsent'] = 'Tweet successfully sent';

#N

#O

#P
$lang['postinstall'] = 'The module has been installed.  Please visit the modules admin panel to set the authorization tokens';
$lang['postuninstall'] = 'The module has been successfully uninstalled, and all data related to this module permanently removed';
$lang['prompt_friendlyname'] = 'Module Friendly Name';
$lang['prompt_shorten_urls'] = 'Shorten URLS';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you want to remove this module?  Uninstalling will remove all known twitter credentials for any users and may break a functioning website.';

#S
$lang['send_test_tweet'] = 'Send Test Tweet';
$lang['settings'] = 'Settings';
$lang['settings_changed'] = 'Settings updated';
$lang['submit'] = 'Submit';

#T
$lang['timelinetemplates'] = 'Timeline Templates';
$lang['title_addedit_authtemplate'] = 'Add or Edit an Authorization Template';
$lang['title_addedit_timeline'] = 'Add or Edit a Timeline Template';
$lang['title_app_settings'] = 'Twitter App Settings';
$lang['title_general_settings'] = 'General Settings';
$lang['title_sysdflt_authtemplate'] = 'System Default Authorization Template';
$lang['title_sysdflt_timeline'] = 'System Default Timeline Template';
$lang['twitter_account_settings'] = 'Twitter Account Settings';

#U

#V
$lang['via'] = 'via';

#W

#X

#Y

#Z

?>
